@@ -3,8 +3,11 @@
 
 /*---
 esid: sec-array.isarray
-es5id: 15.4.3.2-1-8
-description: Array.isArray applied to the Math object
+es5id: 15.4.3.2-0-3
+description: Array.isArray return true if its argument is an Array
 ---*/
 
-assert.sameValue(Array.isArray(Math), false, 'Array.isArray(Math)');
+var a = [];
+var b = Array.isArray(a);
+
+assert.sameValue(b, true, 'b');
