@@ -3,18 +3,19 @@
 
 /*---
 esid: sec-array.prototype.filter
-es5id: 15.4.4.20-5-23
-description: Array.prototype.filter - number primitive can be used as thisArg
+es5id: 15.4.4.20-5-13
+description: Array.prototype.filter - Number Object can be used as thisArg
 ---*/
 
 var accessed = false;
+var objNumber = new Number();
 
 function callbackfn(val, idx, obj) {
   accessed = true;
-  return this.valueOf() === 101;
+  return this === objNumber;
 }
 
-var newArr = [11].filter(callbackfn, 101);
+var newArr = [11].filter(callbackfn, objNumber);
 
 assert.sameValue(newArr[0], 11, 'newArr[0]');
 assert(accessed, 'accessed !== true');
