@@ -2,23 +2,21 @@
 // This code is governed by the BSD license found in the LICENSE file.
 
 /*---
-es5id: 15.3.5.4_2-36gs
+es5id: 15.3.5.4_2-72gs
 description: >
     Strict mode - checking access to strict function caller from
-    non-strict function (FunctionDeclaration defined within an
-    Anonymous FunctionExpression with a strict directive prologue)
+    non-strict function (strict function declaration called by
+    Function.prototype.bind(undefined)())
 flags: [noStrict]
 ---*/
 
-assert.throws(TypeError, function() {
-  (function() {
-    "use strict";
+function f() {
+  "use strict";
+  gNonStrict();
+};
 
-    function f() {
-      gNonStrict();
-    }
-    f();
-  })();
+assert.throws(TypeError, function() {
+  f.bind(undefined)();
 });
 
 function gNonStrict() {
