@@ -2,19 +2,19 @@
 // This code is governed by the BSD license found in the LICENSE file.
 
 /*---
-es5id: 15.2.3.10-3-18
+es5id: 15.2.3.10-3-2
 description: >
-    Object.preventExtensions - named properties cannot be added into a
-    Date object
+    Object.preventExtensions - indexed properties cannot be added into
+    the returned object
 includes: [propertyHelper.js]
 ---*/
 
-var obj = new Date();
+var obj = {};
 
 assert(Object.isExtensible(obj));
 Object.preventExtensions(obj);
 assert(!Object.isExtensible(obj));
 
-verifyNotWritable(obj, "exName", "nocheck");
+verifyNotWritable(obj, "0", "nocheck");
 
-assert(!obj.hasOwnProperty("exName"));
+assert(!obj.hasOwnProperty("0"));
